package org.jeecg.modules.carrentApply.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.carrentApply.entity.CarrentApply;
import org.jeecg.modules.carrentApply.service.ICarrentApplyService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 寻车申请表
 * @Author: jeecg-boot
 * @Date:   2024-12-12
 * @Version: V1.0
 */
@Api(tags="寻车申请表")
@RestController
@RequestMapping("/carrentApply/carrentApply")
@Slf4j
public class CarrentApplyController extends JeecgController<CarrentApply, ICarrentApplyService> {
	@Autowired
	private ICarrentApplyService carrentApplyService;
	
	/**
	 * 分页列表查询
	 *
	 * @param carrentApply
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "寻车申请表-分页列表查询")
	@ApiOperation(value="寻车申请表-分页列表查询", notes="寻车申请表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CarrentApply>> queryPageList(CarrentApply carrentApply,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CarrentApply> queryWrapper = QueryGenerator.initQueryWrapper(carrentApply, req.getParameterMap());
		Page<CarrentApply> page = new Page<CarrentApply>(pageNo, pageSize);
		IPage<CarrentApply> pageList = carrentApplyService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param carrentApply
	 * @return
	 */
	@AutoLog(value = "寻车申请表-添加")
	@ApiOperation(value="寻车申请表-添加", notes="寻车申请表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CarrentApply carrentApply) {
		carrentApplyService.save(carrentApply);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param carrentApply
	 * @return
	 */
	@AutoLog(value = "寻车申请表-编辑")
	@ApiOperation(value="寻车申请表-编辑", notes="寻车申请表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CarrentApply carrentApply) {
		carrentApplyService.updateById(carrentApply);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "寻车申请表-通过id删除")
	@ApiOperation(value="寻车申请表-通过id删除", notes="寻车申请表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		carrentApplyService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "寻车申请表-批量删除")
	@ApiOperation(value="寻车申请表-批量删除", notes="寻车申请表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.carrentApplyService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "寻车申请表-通过id查询")
	@ApiOperation(value="寻车申请表-通过id查询", notes="寻车申请表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CarrentApply> queryById(@RequestParam(name="id",required=true) String id) {
		CarrentApply carrentApply = carrentApplyService.getById(id);
		if(carrentApply==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(carrentApply);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param carrentApply
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CarrentApply carrentApply) {
        return super.exportXls(request, carrentApply, CarrentApply.class, "寻车申请表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CarrentApply.class);
    }

}
