package org.jeecg.modules.carrentCategoryone.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.carrentCategoryone.entity.CarrentCategoryone;
import org.jeecg.modules.carrentCategoryone.service.ICarrentCategoryoneService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 商品一级分类
 * @Author: jeecg-boot
 * @Date:   2024-12-12
 * @Version: V1.0
 */
@Api(tags="商品一级分类")
@RestController
@RequestMapping("/carrentCategoryone/carrentCategoryone")
@Slf4j
public class CarrentCategoryoneController extends JeecgController<CarrentCategoryone, ICarrentCategoryoneService> {
	@Autowired
	private ICarrentCategoryoneService carrentCategoryoneService;
	
	/**
	 * 分页列表查询
	 *
	 * @param carrentCategoryone
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "商品一级分类-分页列表查询")
	@ApiOperation(value="商品一级分类-分页列表查询", notes="商品一级分类-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CarrentCategoryone>> queryPageList(CarrentCategoryone carrentCategoryone,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CarrentCategoryone> queryWrapper = QueryGenerator.initQueryWrapper(carrentCategoryone, req.getParameterMap());
		Page<CarrentCategoryone> page = new Page<CarrentCategoryone>(pageNo, pageSize);
		IPage<CarrentCategoryone> pageList = carrentCategoryoneService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param carrentCategoryone
	 * @return
	 */
	@AutoLog(value = "商品一级分类-添加")
	@ApiOperation(value="商品一级分类-添加", notes="商品一级分类-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CarrentCategoryone carrentCategoryone) {
		carrentCategoryoneService.save(carrentCategoryone);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param carrentCategoryone
	 * @return
	 */
	@AutoLog(value = "商品一级分类-编辑")
	@ApiOperation(value="商品一级分类-编辑", notes="商品一级分类-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CarrentCategoryone carrentCategoryone) {
		carrentCategoryoneService.updateById(carrentCategoryone);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "商品一级分类-通过id删除")
	@ApiOperation(value="商品一级分类-通过id删除", notes="商品一级分类-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		carrentCategoryoneService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "商品一级分类-批量删除")
	@ApiOperation(value="商品一级分类-批量删除", notes="商品一级分类-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.carrentCategoryoneService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "商品一级分类-通过id查询")
	@ApiOperation(value="商品一级分类-通过id查询", notes="商品一级分类-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CarrentCategoryone> queryById(@RequestParam(name="id",required=true) String id) {
		CarrentCategoryone carrentCategoryone = carrentCategoryoneService.getById(id);
		if(carrentCategoryone==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(carrentCategoryone);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param carrentCategoryone
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CarrentCategoryone carrentCategoryone) {
        return super.exportXls(request, carrentCategoryone, CarrentCategoryone.class, "商品一级分类");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CarrentCategoryone.class);
    }

}
